from distutils.core import setup

setup(
    name = 'skfunctions',
    version = '1.0.0',
    py_modules = ['skfunctions'],
    author = 'sujan kumar',
    author_email = 'dhodiumsujankumar@gmail.com',
    url = 'http://www.dsujankumar.com',
    description = 'two simple functions'
    )
